Author: New York City Streets Renaissance

# The New York City Streets Renaissance

- Home Page
- Join Us

New York is a city best enjoyed on foot, yet we plan our streets for cars.

New York City's streets are the soul of its neighborhoods and the pathways to some of the world's most in-demand destinations. For generations, New Yorkers and visitors have strolled, shopped and socialized on sidewalks and street corners. Pedestrian friendly streets are the city's most fundamental assets.

Unfortunately, we aren't making the most of these assets. Instead, our streets are being managed almost entirely for traffic flow, with neighborhoods and business districts buckling under increasing amounts of dangerous car and truck traffic. If we continue planning our streets for cars and traffic, we will get more cars and traffic; conversely, if we start planning our cities for people and places, we will get more people and places.

Streets are more than just car corridors; they are valuable civic spaces and resources that need to be wisely allocated. The New York City Streets Renaissance Campaign is building the movement to re-imagine our streets as lively public places.

#### Goals of the New York City Streets Renaissance

- Educate New Yorkers about potential transportation policy changes that will improve quality of life across New York City
- Promote a rebalancing of this public space away from private vehicles and toward community needs
- Demonstrate the widespread public support for reform on these issues
- Tap the potential of New Yorkers to re-imagine their own streets

The choice is clear: either we choose to be defined by worsening traffic and perilous streets or we can define ourselves through great public spaces and lively streets. Through action and dialogue New Yorkers can raise expectations for their public realm. Join our city-wide campaign for local improvements that reflect your neighborhood's unique character.